@@ -1,6 +1,6 @@
 package Ubic::Service::SimpleDaemon;
 {
-  $Ubic::Service::SimpleDaemon::VERSION = '1.43_01';
+  $Ubic::Service::SimpleDaemon::VERSION = '1.43_02';
 }
 
 use strict;
@@ -51,7 +51,11 @@ sub new {
     });
 
     if ($params->{ulimit}) {
-        require BSD::Resource; # fast fail if BSD::Resource is not installed
+        # load BSD::Resource lazily, but fail fast if we're asked for it
+        eval "require BSD::Resource";
+        if ($@) {
+            die "BSD::Resource is not installed";
+        }
     }
 
     return bless {%$params} => $class;
@@ -152,7 +156,7 @@ Ubic::Service::SimpleDaemon - service module for daemonizing any binary
 
 =head1 VERSION
 
-version 1.43_01
+version 1.43_02
 
 =head1 SYNOPSIS
 
